@@ -146,6 +146,7 @@ class FakeActionQueue(object):
         self.eq = self.event_queue = eq
         self.uuid_map = action_queue.DeferredMap()
         self.queue = action_queue.RequestQueue(self)
+        self.pathlock = FakedObject()
 
         # throttling attributes
         self.readLimit = None
@@ -215,12 +216,52 @@ class FakeStatusListener(object):
         return {RECENT_TRANSFERS: [], UPLOADING: []}
 
 
+class FakeMonitor(object):
+    """A fake FilesystemMonitor."""
+
+    def __init__(self, eq, fs, ignore_config=None, timeout=1):
+        """Do nothing."""
+
+    def freeze_begin(self, path):
+        """Succeed quietly."""
+
+    def freeze_rollback(self):
+        """Succeed quietly."""
+
+    def freeze_commit(self, events):
+        """Never report dirty commits for fake events."""
+        return defer.succeed(False)
+
+    def add_to_mute_filter(self, event, **info):
+        """Do nothing."""
+
+    def rm_from_mute_filter(self, event, **info):
+        """Do nothing."""
+
+    def add_watches_to_udf_ancestors(self, volume):
+        """Just report success."""
+        return defer.succeed(True)
+
+    def add_watch(self, dirpath):
+        """Just report success."""
+        defer.succeed(True)
+
+    def rm_watch(self, dirpath):
+        """Just report success."""
+        return defer.succeed(True)
+
+    def shutdown(self):
+        """Just report success."""
+        return defer.succeed(True)
+
+
 class FakeMain(main.Main):
     """ A fake Main class to setup the tests """
 
     _fake_AQ_class = FakeActionQueue
     _fake_AQ_params = ()
     _sync_class = None
+    _monitor_class = FakeMonitor
 
     # don't call Main.__init__ we take care of creating a fake main and
     # all its attributes. pylint: disable=W0231
@@ -236,7 +277,8 @@ class FakeMain(main.Main):
         self.vm = volume_manager.VolumeManager(self)
         self.fs = fs_manager.FileSystemManager(
             self.data_dir, self.partials_dir, self.vm, self.db)
-        self.event_q = event_queue.EventQueue(self.fs)
+        self.event_q = event_queue.EventQueue(self.fs,
+                                              monitor_class=self._monitor_class)
         self.fs.register_eq(self.event_q)
         self.action_q = self._fake_AQ_class(self.event_q, self,
                                             *self._fake_AQ_params)
