@@ -33,7 +33,7 @@
 import apport
 from apport.hookutils import attach_file_if_exists
 import os.path
-from xdg.BaseDirectory import xdg_cache_home, xdg_config_home
+from dirspec.basedir import xdg_cache_home, xdg_config_home
 
 # Paths where things we might want live
 u1_log_path = os.path.join(xdg_cache_home, "ubuntuone", "log")
