@@ -274,6 +274,15 @@ class FileSystemTests(FileSystemTestCase):
         self.assert_remote_method('get_metadata',
             in_signature='s', out_signature='a{ss}')
 
+    @defer.inlineCallbacks
+    def test_search_files(self):
+        """Test get_metadata."""
+        result = ['path']
+        yield self.assert_method_called(self.service.file_system,
+                                        'search_files', result, 'file')
+        self.assert_remote_method('search_files',
+            in_signature='s', out_signature='as')
+
     @defer.inlineCallbacks
     def test_get_metadata_by_node(self):
         """Test get_metadata_by_node."""
@@ -520,6 +529,7 @@ class AutoconnectConfigTests(ConfigTests):
 
     setting_name = 'autoconnect'
 
+    @defer.inlineCallbacks
     def test_set_autoconnect_enabled(self):
         """Test for Config.set_autoconnect_enabled.
 
@@ -530,11 +540,11 @@ class AutoconnectConfigTests(ConfigTests):
 
         yield client.call_method('set_autoconnect_enabled', True)
         called = self.service.config._called['enable_autoconnect']
-        self.assertEqual(called, [()])
+        self.assertEqual(called, [((), {})])
 
         yield client.call_method('set_autoconnect_enabled', False)
         called = self.service.config._called['disable_autoconnect']
-        self.assertEqual(called, [()])
+        self.assertEqual(called, [((), {})])
 
 
 class ShowAllNotificationsConfigTests(ConfigTests):
