@@ -572,9 +572,10 @@ class ZeitgeistRemoteFileSyncTestCase(ConnectedBaseTestCase):
             """Just to allow monkeypatching."""
 
         self.share_id = ""
+        self.mdid = self.main.fs.create(os.path.join(self.root, 'file'), '')
         self.command = MyUpload(request_queue, share_id=self.share_id,
                                 node_id='a_node_id', previous_hash='prev_hash',
-                                hash='yadda', crc32=0, size=0, path='path')
+                                hash='yadda', crc32=0, size=0, mdid=self.mdid)
         self.command.make_logger()
         self.command.tempfile = FakeTempFile(self.mktemp('tmpdir'))
         self.fsm = self.action_queue.main.fs
@@ -599,7 +600,7 @@ class ZeitgeistRemoteFileSyncTestCase(ConnectedBaseTestCase):
 
         # create a command and trigger it success
         cmd = MakeFile(self.rq, self.share_id, 'parent', filename,
-                       'marker', path)
+                       'marker', self.mdid)
         cmd.handle_success(request)
 
         # create a request and fill it with succesful information
@@ -657,7 +658,7 @@ class ZeitgeistRemoteFileSyncTestCase(ConnectedBaseTestCase):
 
         # create a command and trigger it success
         cmd = MakeDir(self.rq, self.share_id, 'parent',
-                      dirname, 'marker', path)
+                      dirname, 'marker', self.mdid)
         cmd.handle_success(request)
 
         # check for successful event
