@@ -34,8 +34,9 @@ from collections import defaultdict
 
 from twisted.internet import defer, reactor
 from ubuntuone.devtools.handlers import MementoHandler
+from ubuntuone.devtools.testcases import skipTest, skipIfNotOS
 
-from contrib.testing.testcase import FakeCommand, skipIfOS
+from contrib.testing.testcase import FakeCommand
 
 from ubuntuone.syncdaemon import (
     action_queue,
@@ -77,7 +78,7 @@ class TestToolsBase(IPCTestCase):
 
         self.patch(tools, 'is_already_running',
                    lambda bus: defer.succeed(True))
-        yield self.main.wait_for_nirvana()
+        yield self.main.wait_for_nirvana(last_event_interval=0.001)
 
     def _create_share(self, accepted=True, subscribed=True):
         """Return a newly created Share."""
@@ -123,22 +124,6 @@ class TestToolsBasic(TestToolsBase):
         result = yield self.tool.wait_connected()
         self.assertEqual(True, result)
 
-    def test_wait_no_more_events(self):
-        """Test wait_no_more_events."""
-        d = self.tool.wait_no_more_events(last_event_interval=.1)
-
-        self.event_q.push("FS_FILE_CREATE", path="somepath")
-
-        def check(result):
-            """Check result."""
-            self.assertTrue(self.handler.check_debug("new event",
-                                                     "FS_FILE_CREATE"))
-            self.assertTrue(self.handler.check_debug("No more events"))
-            self.assertEqual(True, result)
-
-        d.addBoth(check)
-        return d
-
     def test_all_downloads(self):
         """ test wait_all_downloads """
         d = self.tool.wait_all_downloads()
@@ -202,6 +187,27 @@ class TestToolsBasic(TestToolsBase):
         self.assertEqual('', str(result['share_id']))
         self.assertEqual('node_id', result['node_id'])
 
+    @skipTest('Fails in nightlies: bug #1071466')
+    @defer.inlineCallbacks
+    def test_search_files(self):
+        """Check that get_metadata works as expected."""
+        mdid = 'id'
+        path = os.path.join(self.root_dir, u'path/to/file_test')
+        mdobj = {'server_hash': 'asdqwe123'}
+        mdid2 = 'id2'
+        path2 = os.path.join(self.root_dir, u'path/to/my_files')
+        mdobj2 = {'server_hash': 'asdqwe456'}
+        mdid3 = 'id3'
+        path3 = u'/home2/to/my_files'
+        mdobj3 = {'server_hash': 'asdqwe456'}
+        self.fs._idx_path = {path: mdid, path2: mdid2, path3: mdid3}
+        self.fs.fs = {mdid: mdobj, mdid2: mdobj2, mdid3: mdobj3}
+
+        result = yield self.tool.search_files('file')
+        expected = [os.path.join(self.root_dir, 'path/to/file_test'),
+            os.path.join(self.root_dir, 'path/to/my_files')]
+        self.assertEqual(result, expected)
+
     @defer.inlineCallbacks
     def test_quit_when_running(self):
         """Test the quit method when the daemon is running."""
@@ -992,7 +998,8 @@ class TestToolsSomeMore(TestToolsBase):
         vol_id = yield d
         self.assertEqual(vol_id, udf.volume_id)
 
-    @skipIfOS('win32', 'exceptions are not properly raised from PB.')
+    @skipIfNotOS('linux2',
+                 "Exception is raised twice from PB in same process.")
     @defer.inlineCallbacks
     def test_rescan_from_scratch_missing_volume(self):
         """Test for rescan_from_scratch method with a non-existing volume.."""
