@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
 #
-# Copyright 2012 Canonical Ltd.
+# Copyright 2012-2013 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -569,7 +569,7 @@ class FakeNetworkProxyFactoryClass(object):
         if enabled:
             self.proxy_type = tunnel_server.QNetworkProxy.HttpProxy
         else:
-            self.proxy_type = tunnel_server.QNetworkProxy.DefaultProxy
+            self.proxy_type = tunnel_server.QNetworkProxy.NoProxy
 
     def type(self):
         """Return the proxy type configured."""
@@ -729,3 +729,11 @@ class MainFunctionTestCase(TestCase):
         self.proxies_enabled = True
         tunnel_server.main(["example.com", "443"])
         self.assertEqual(len(installed), 0)
+
+    def test_fix_turkish_locale_called(self):
+        """The fix_turkish_locale function is called, always."""
+        called = []
+        self.patch(tunnel_server, "fix_turkish_locale",
+                   lambda *args, **kwargs: called.append((args, kwargs)))
+        tunnel_server.main(["localhost", "443"])
+        self.assertEqual(called, [((), {})])
