@@ -34,15 +34,17 @@
 import functools
 import logging
 import os
+import sys
 
 from twisted.internet import defer, reactor
 from ubuntuone.devtools.handlers import MementoHandler
-from ubuntuone.devtools.testcases import skipIfOS
+from ubuntuone.devtools.testcases import skipIfOS, skipIfNotOS
 
 from contrib.testing.testcase import (
     BaseTwistedTestCase,
     FakeMain,
     Listener,
+    skip_if_darwin_missing_fs_event,
     skip_if_win32_missing_fs_event,
 )
 from tests.syncdaemon.test_eventqueue import BaseEQTestCase
@@ -182,6 +184,9 @@ class BaseTwisted(BaseEQTestCase):
     # this timeout must be bigger than the one used in event_queue
     timeout = 2
 
+    # use the default FSMonitor
+    _monitor_class = None
+
     @defer.inlineCallbacks
     def setUp(self):
         """Setup the test."""
@@ -330,6 +335,7 @@ class FreezeTests(BaseTwisted):
         yield self._deferred
 
     @skip_if_win32_missing_fs_event
+    @skip_if_darwin_missing_fs_event
     @defer.inlineCallbacks
     def test_commit_middle_events(self):
         """Commit behaviour when something happened in the middle."""
@@ -396,6 +402,7 @@ class FreezeTests(BaseTwisted):
         yield self._deferred
 
     @skip_if_win32_missing_fs_event
+    @skip_if_darwin_missing_fs_event
     @defer.inlineCallbacks
     def test_selective(self):
         """Check that it's frozen only for a path."""
@@ -633,6 +640,8 @@ class MutedSignalsTests(BaseTwisted):
         make_dir(root_dir)
         open_file(fromfile, "w").close()
         self.eq.add_to_mute_filter("FS_FILE_CREATE", path=tofile)
+        if sys.platform == 'darwin':
+            self.eq.add_to_mute_filter("FS_FILE_OPEN", path=tofile)
         self.eq.add_to_mute_filter("FS_FILE_CLOSE_WRITE", path=tofile)
 
         yield self.eq.add_watch(root_dir)
@@ -646,7 +655,7 @@ class MutedSignalsTests(BaseTwisted):
         yield self._deferred
 
 
-@skip_if_win32_missing_fs_event
+@skipIfNotOS('linux2', "Only Linux watches UDF ancestors")
 class AncestorsUDFTestCase(BaseTwistedTestCase):
     """Events over UDF's ancestor are properly handled."""
 
@@ -661,6 +670,7 @@ class AncestorsUDFTestCase(BaseTwistedTestCase):
         self.data_dir = self.mktemp('data_dir')
         self.shares_dir = self.mktemp('shares_dir')
         self.partials_dir = self.mktemp('partials_dir')
+        self.patch(FakeMain, '_monitor_class', None)
         self.main = FakeMain(self.root_dir, self.shares_dir,
                              self.data_dir, self.partials_dir)
         self.addCleanup(self.main.shutdown)
@@ -988,6 +998,7 @@ class AncestorsUDFTestCase(BaseTwistedTestCase):
 
 
 @skipIfOS('win32', "we can't create files with invalid utf8 byte sequences.")
+@skipIfOS('darwin', "fsevents daemon ignores events with invalid filenames")
 class NonUTF8NamesTests(BaseTwisted):
     """Test the non-utf8 name handling."""
 
@@ -1160,6 +1171,7 @@ class NonUTF8NamesTests(BaseTwisted):
 
 
 @skip_if_win32_missing_fs_event
+@skip_if_darwin_missing_fs_event
 class SignalingTests(BaseTwisted):
     """Test the whole stuff to receive signals."""
 
