@@ -33,7 +33,10 @@ import os
 
 from twisted.internet import defer
 from ubuntuone.devtools.handlers import MementoHandler
-from ubuntu_sso.networkstate import ONLINE
+from ubuntu_sso.networkstate.networkstates import ONLINE
+from tests.platform.ipc.test_perspective_broker import (
+    FakeNetworkManagerState
+)
 
 from contrib.testing.testcase import (
     FakeCommand,
@@ -2196,6 +2199,8 @@ class SyncdaemonServiceTestCase(BaseTestCase):
     @defer.inlineCallbacks
     def setUp(self):
         """Init."""
+        self.patch(interaction_interfaces, 'NetworkManagerState',
+                   FakeNetworkManagerState)
         yield super(SyncdaemonServiceTestCase, self).setUp()
         self.events = []
         self.sd_obj.main.event_q.push = lambda name, **kw: \
@@ -2335,6 +2340,8 @@ class SyncdaemonServiceConnectTestCase(BaseTestCase):
     @defer.inlineCallbacks
     def setUp(self):
         """Init."""
+        self.patch(interaction_interfaces, 'NetworkManagerState',
+                   FakeNetworkManagerState)
         self.patch(credentials, 'CredentialsManagementTool',
                    FakedCredentialsManagementTool)
         yield super(SyncdaemonServiceConnectTestCase, self).setUp()
