@@ -682,3 +682,276 @@ class LoggingTests(TwistedTestCase):
         self.assertTrue(self.handler.check_debug("releasing",
                                                  "'a', 'b', 'c', 'd', 'e'",
                                                  "remaining: 4"))
+
+
+class PathFixingTests(TwistedTestCase):
+    """Test the path fixing."""
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Set up."""
+        yield super(PathFixingTests, self).setUp()
+        self.plt = PathLockingTree()
+
+        self.handler = MementoHandler()
+        self.plt.logger.setLevel(logging.DEBUG)
+        self.plt.logger.propagate = False
+        self.plt.logger.addHandler(self.handler)
+        self.addCleanup(self.plt.logger.removeHandler, self.handler)
+
+    def test_clean_pathlocktree(self):
+        """A fix over nothing stored."""
+        self.plt.fix_path(tuple('abc'), tuple('abX'))
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_simple_leaf(self):
+        """Simple change for a leaf."""
+        from_path = tuple('abc')
+        to_path = tuple('abX')
+        release = yield self.plt.acquire(*from_path)
+
+        # get leaf deferred
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_c = node_b['children_nodes']['c']
+        original_deferreds = node_c['node_deferreds']
+
+        # fix path
+        self.plt.fix_path(from_path, to_path)
+
+        # get deferred from new path, assert is the same
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_X = node_b['children_nodes']['X']
+        self.assertEqual(node_X['node_deferreds'], original_deferreds)
+
+        # release, it should be clean now
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_complex_leaf(self):
+        """Change for a leaf with two items."""
+        from_path = tuple('abc')
+        to_path = tuple('abX')
+
+        releases = []
+        d = self.plt.acquire(*from_path)
+        d.addCallback(releases.append)
+        d = self.plt.acquire(*from_path)
+        d.addCallback(releases.append)
+
+        # get leaf deferred
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_c = node_b['children_nodes']['c']
+        original_deferreds = node_c['node_deferreds']
+
+        # rename
+        self.plt.fix_path(from_path, to_path)
+
+        # get deferred from new path, assert is the same
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_X = node_b['children_nodes']['X']
+        self.assertEqual(node_X['node_deferreds'], original_deferreds)
+
+        # acquire with other one, assert that it's not released
+        d = self.plt.acquire(*to_path)
+        d.addCallback(lambda f: self.assertFalse(releases) or f)
+
+        # release
+        releases.pop(0)()
+        releases.pop(0)()
+        release = yield d
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_simple_not_leaf(self):
+        """Simple change for not a leaf."""
+        from_path = tuple('abc')
+        to_path = tuple('aXc')
+        releases = []
+        d = self.plt.acquire(*from_path)
+        d.addCallback(releases.append)
+
+        # get leaf deferred
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_c = node_b['children_nodes']['c']
+        original_deferreds = node_c['node_deferreds']
+
+        # rename
+        self.plt.fix_path(from_path, to_path)
+
+        # get deferred from new path, assert is the same
+        node_a = self.plt.root['children_nodes']['a']
+        node_X = node_a['children_nodes']['X']
+        node_c = node_X['children_nodes']['c']
+        self.assertEqual(node_c['node_deferreds'], original_deferreds)
+
+        # acquire with other one, assert that it's not released
+        d = self.plt.acquire(*to_path)
+        d.addCallback(lambda f: self.assertFalse(releases) or f)
+
+        # release
+        releases.pop(0)()
+        release = yield d
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_same_tree(self):
+        """Move a leaf one level up."""
+        from_path = tuple('abcd')
+        to_path = tuple('abd')
+        releases = []
+        d = self.plt.acquire(*from_path)
+        d.addCallback(releases.append)
+
+        # get leaf deferred
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_c = node_b['children_nodes']['c']
+        node_d = node_c['children_nodes']['d']
+        original_deferreds = node_d['node_deferreds']
+
+        # rename
+        self.plt.fix_path(from_path, to_path)
+
+        # get deferred from new path, assert is the same
+        node_a = self.plt.root['children_nodes']['a']
+        node_b = node_a['children_nodes']['b']
+        node_d = node_b['children_nodes']['d']
+        self.assertEqual(node_d['node_deferreds'], original_deferreds)
+
+        # check also that the 'c' node is gone
+        self.assertNotIn('c', node_b['children_nodes'])
+
+        # acquire with other one, assert that it's not released
+        d = self.plt.acquire(*to_path)
+        d.addCallback(lambda f: self.assertFalse(releases) or f)
+
+        # release
+        releases.pop(0)()
+        release = yield d
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_parents_move_child(self):
+        """Complex change involving parents, renaming child."""
+        releases = []
+        d = self.plt.acquire('a', 'b')
+        d.addCallback(releases.append)
+        d = self.plt.acquire('a', 'b', 'c', on_parent=True)
+        d.addCallback(releases.append)
+
+        # rename
+        self.plt.fix_path(('a', 'b', 'c'), ('a', 'b', 'X'))
+
+        # acquire with other one, assert that it's not released
+        d = self.plt.acquire('a', 'b', 'X')
+        d.addCallback(lambda f: self.assertFalse(releases) or f)
+
+        # release
+        releases.pop(0)()
+        releases.pop(0)()
+        release = yield d
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_parents_move_parent(self):
+        """Complex change involving parents, renaming parent."""
+        releases = []
+        d = self.plt.acquire('a', 'b')
+        d.addCallback(releases.append)
+        d = self.plt.acquire('a', 'b', 'c', on_parent=True)
+        d.addCallback(releases.append)
+
+        # rename
+        self.plt.fix_path(('a', 'b'), ('a', 'X'))
+
+        # acquire with other one, assert that there's only one
+        # left to release ('aXC', as releasing 'aX' will trigger
+        # this one)
+        d = self.plt.acquire('a', 'X', 'd', on_parent=True)
+        d.addCallback(lambda f: self.assertEqual(len(releases), 1) and f)
+
+        # release first the parent, then the child
+        releases.pop(0)()
+        releases.pop(0)()
+        release = yield d
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    @defer.inlineCallbacks
+    def test_very_different_children(self):
+        """Aquire changing the children a lot."""
+        releases = []
+        d = self.plt.acquire('a', 'b', 'c', 'd')
+        d.addCallback(releases.append)
+        d = self.plt.acquire('a', 'b', 'c', on_children=True)
+        d.addCallback(releases.append)
+
+        # rename
+        self.plt.fix_path(('a', 'b', 'c', 'd'), ('a', 'b', 'X', 'Y'))
+
+        # acquire with other one, assert that there's only one
+        # left to release ('aXC', as releasing 'aX' will trigger
+        # this one)
+        d = self.plt.acquire('a', 'b', 'X', on_children=True)
+        d.addCallback(lambda f: self.assertEqual(len(releases), 1) and f)
+
+        # release first the parent, then the child
+        releases.pop(0)()
+        releases.pop(0)()
+        release = yield d
+        release()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    def test_double_simple(self):
+        """Simple but duplicate acquiring."""
+        releases = []
+        d = self.plt.acquire('GetDelta', '')
+        d.addCallback(releases.append)
+        d = self.plt.acquire('GetDelta', '')
+        d.addCallback(releases.append)
+        releases.pop(0)()
+        releases.pop(0)()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    def test_moving_over(self):
+        """Move over something that still exists."""
+        releases = []
+        d = self.plt.acquire('a', 'b', 'c')
+        d.addCallback(releases.append)
+        d = self.plt.acquire('a', 'b', 'd')
+        d.addCallback(releases.append)
+
+        # rename
+        self.plt.fix_path(('a', 'b', 'd'), ('a', 'b', 'c'))
+
+        # release both
+        releases.pop(0)()
+        releases.pop(0)()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
+
+    def test_irl_complicated_example(self):
+        """Just a complicated move I found IRL."""
+        releases = []
+        d = self.plt.acquire('temp', 'drizzle', '.bzr', 'checkout', 'limbo',
+                             'new-19', 'handshake.cc')
+        d.addCallback(releases.append)
+
+        # rename
+        fix_from = ('temp', 'drizzle', '.bzr', 'checkout', 'limbo', 'new-19')
+        fix_to = ('temp', 'drizzle', 'libdrizzle')
+        self.plt.fix_path(fix_from, fix_to)
+
+        # release it
+        releases.pop(0)()
+        self.assertEqual(len(self.plt.root['children_nodes']), 0)
