@@ -1,7 +1,5 @@
 # -*- coding: utf-8 -*-
 #
-# Author: Guillermo Gonzalez <guillermo.gonzalez@canonical.com>
-#
 # Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
@@ -299,19 +297,21 @@ class BaseSync(BaseTwistedTestCase):
         yield self.fsm.vm.add_share(share)
         defer.returnValue(share)
 
-
-class TestSync(BaseSync):
-    """Test for Sync."""
-
+class TestUsingRealFSMonitor(BaseSync):
+    """Class for tests that require a real FS monitor."""
     timeout = 3
 
     @defer.inlineCallbacks
     def setUp(self):
-        """Set up."""
-        yield super(TestSync, self).setUp()
-        self.sync = Sync(main=self.main)
-        self.fsm = self.main.fs
-        self.handler.setLevel(logging.DEBUG)
+        """Override self.main from BaseSync."""
+        yield super(TestUsingRealFSMonitor, self).setUp()
+        # FakeMain sends _monitor_class to EventQueue, which
+        # uses platform default monitor when given None:
+        self.patch(FakeMain, "_monitor_class", None)
+        self.main = FakeMain(root_dir=self.root, shares_dir=self.shares,
+                             data_dir=self.data,
+                             partials_dir=self.partials_dir)
+        self.addCleanup(self.main.shutdown)
 
     @skipIfOS('win32', 'In windows we can not unlink opened files.')
     def test_deleting_open_files_is_no_cause_for_despair(self):
@@ -333,6 +333,19 @@ class TestSync(BaseSync):
         d.addCallback(cb)
         return d
 
+class TestSync(BaseSync):
+    """Test for Sync."""
+
+    timeout = 3
+
+    @defer.inlineCallbacks
+    def setUp(self):
+        """Set up."""
+        yield super(TestSync, self).setUp()
+        self.sync = Sync(main=self.main)
+        self.fsm = self.main.fs
+        self.handler.setLevel(logging.DEBUG)
+
     def test_handle_AQ_DOWNLOAD_DOES_NOT_EXIST(self):
         """handle_AQ_DOWNLOAD_DOES_NOT_EXIST."""
         self.called = False
@@ -1322,9 +1335,10 @@ class SyncStateMachineRunnerTestCase(BaseSync):
         # patch HQ to don't hash the file
         self.main.hash_q.insert = lambda *a: None
 
-        # record the call
+        # record the calls
         called = []
         self.main.fs.add_to_move_limbo = lambda *a: called.append(a)
+        self.main.action_q.pathlock.fix_path = lambda *a: called.append(a)
 
         # create context and call
         key = FSKey(self.main.fs, path=somepath1)
@@ -1332,8 +1346,10 @@ class SyncStateMachineRunnerTestCase(BaseSync):
                                       key=key, logger=None)
         parent_id = FSKey(self.main.fs, path=self.root)['node_id']
         ssmr.client_moved('some event', {}, somepath1, somepath2)
-        self.assertEqual(called, [('', 'node_id', parent_id, parent_id,
-                                   'bar', somepath1, somepath2)])
+        self.assertEqual(called[0], (tuple(somepath1.split(os.path.sep)),
+                                     tuple(somepath2.split(os.path.sep))))
+        self.assertEqual(called[1], ('', 'node_id', parent_id, parent_id,
+                                     'bar', somepath1, somepath2))
 
     def test_clean_move_limbo(self):
         """Clean the move limbo with what was called."""
