@@ -1,8 +1,5 @@
 # -*- coding: utf-8 -*-
 #
-# Author: Natalia B. Bidart <natalia.bidart@canonical.com>
-# Author: Manuel de la Pena<manuel@canonical.com>
-#
 # Copyright 2011-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
@@ -57,7 +54,7 @@ from ubuntuone.logger import (
     CustomRotatingFileHandler,
     log_call,
 )
-from ubuntuone.platform.xdg_base_directory import ubuntuone_log_dir
+from ubuntuone.platform.logger import ubuntuone_log_dir
 
 LOG_LEVEL = logging.DEBUG
 path = os.path.join(ubuntuone_log_dir, 'credentials.log')
@@ -138,12 +135,12 @@ class CredentialsManagementTool(object):
 
     def get_platform_source(self):
         """Platform-specific source."""
-        if sys.platform == 'win32':
-            from ubuntuone.platform.credentials import windows
-            source = windows
+        if sys.platform in ('win32', 'darwin'):
+            from ubuntuone.platform.credentials import ipc_service
+            source = ipc_service
         else:
-            from ubuntuone.platform.credentials import linux
-            source = linux
+            from ubuntuone.platform.credentials import dbus_service
+            source = dbus_service
         return source
 
     @defer.inlineCallbacks
