@@ -491,6 +491,7 @@ class FileSystem(IPCExposedObject):
         'get_metadata_by_node',
         'get_metadata_and_quick_tree_synced',
         'get_dirty_nodes',
+        'search_files',
     ]
 
     def get_metadata(self, path):
@@ -515,6 +516,10 @@ class FileSystem(IPCExposedObject):
         """Return a list of dirty nodes."""
         return self.service.file_system.get_dirty_nodes()
 
+    def search_files(self, pattern):
+        """Search for the occurrence of pattern in the files names."""
+        return self.service.file_system.search_files(pattern)
+
 
 class Shares(IPCExposedObject):
     """An interface to interact with shares."""
