@@ -30,7 +30,6 @@
 
 import logging
 import sys
-import time
 import warnings
 
 from twisted.internet import defer
@@ -161,62 +160,6 @@ class SyncDaemonTool(object):
         d.addCallback(reply_handler)
         return d
 
-    @log_call(logger.debug)
-    def wait_no_more_events(self, last_event_interval, verbose=False):
-        """Wait until no more events are fired by the syncdaemon."""
-        from twisted.internet import reactor
-        d = defer.Deferred()
-
-        def check_last_event():
-            """Check time!
-
-            Check if the daemon is connected and didn't received any events
-            in the last_event_interval.
-
-            """
-            current_time = time.time()
-            if self.last_event and \
-               current_time - self.last_event < last_event_interval:
-                # keep it running in case this is the last event
-                self.log.debug('rescheduling wait_no_more_events')
-                if not self.delayed_call.active():
-                    self.delayed_call = reactor.callLater(last_event_interval,
-                                                          check_last_event)
-                else:
-                    self.delayed_call.reset(last_event_interval)
-            else:
-                self.log.debug('wait_no_more_events: No more events!')
-                d.callback(True)
-
-        if verbose:
-            sys.stdout.write("Listening events")
-            sys.stdout.flush()
-
-        def event_handler(event_dict):
-            """Update last_event and run checks."""
-            self.last_event = time.time()
-            self.log.debug('wait_no_more_events - new event: %s - %s',
-                           event_dict['event_name'], str(self.last_event))
-            if verbose:
-                sys.stdout.write('.')
-                sys.stdout.flush()
-            if self.delayed_call.active():
-                self.delayed_call.reset(last_event_interval)
-
-        match = self.connect_signal(signal_name='Event', handler=event_handler)
-
-        def cleanup(result):
-            """Remove the signal handler."""
-            self.disconnect_signal(signal_name='Event', handler_or_match=match)
-            return result
-
-        d.addBoth(cleanup)
-
-        # in case the daemon already reached nirvana
-        self.delayed_call = reactor.callLater(last_event_interval,
-                                              check_last_event)
-        return d
-
     @log_call(logger.debug)
     def wait_for_nirvana(self, last_event_interval=5, verbose=False):
         """Wait until the syncdaemon reachs nirvana.
@@ -482,6 +425,11 @@ class SyncDaemonTool(object):
         """Get metadata for 'path'."""
         return self.proxy.call_method('file_system', 'get_metadata', path)
 
+    @log_call(logger.debug)
+    def search_files(self, pattern):
+        """Get the files that matches the pattern."""
+        return self.proxy.call_method('file_system', 'search_files', pattern)
+
     @defer.inlineCallbacks
     @log_call(logger.debug)
     def change_public_access(self, path, is_public):
@@ -504,7 +452,7 @@ class SyncDaemonTool(object):
         """Get the public files list."""
         d = self.wait_for_signals('PublicFilesList', 'PublicFilesListError')
         self.proxy.call_method('public_files', 'get_public_files')
-        response, = yield d
+        response, = yield d  # unpacking single element tuple
         defer.returnValue(response)
 
     @defer.inlineCallbacks
