@@ -42,7 +42,8 @@ from ubuntuone.proxy.common import (
 
 METHOD_LINE = "CONNECT %s:%d HTTP/1.0" + CRLF
 LOCALHOST = "127.0.0.1"
-logger = logging.getLogger("ubuntuone.Proxy.TunnelClient")
+
+logger = logging.getLogger("ubuntuone.SyncDaemon.TunnelClient")
 
 
 class TunnelClientProtocol(BaseTunnelProtocol):
@@ -166,6 +167,7 @@ class TunnelProcessProtocol(protocol.ProcessProtocol):
     def finish_timeout(self):
         """Stop the timer from firing."""
         if self.timer and self.timer.active():
+            logger.debug("canceling timer before connection timeout")
             self.timer.cancel()
 
     def processExited(self, status):
@@ -173,6 +175,7 @@ class TunnelProcessProtocol(protocol.ProcessProtocol):
         self.finish_timeout()
         logger.info("Tunnel process exit status %r.", status)
         if not self.client_d.called:
+            logger.debug("Tunnel process exited before TunnelClient created. Falling back to reactor")
             self.client_d.callback(reactor)
 
     def outReceived(self, data):
@@ -192,3 +195,6 @@ class TunnelProcessProtocol(protocol.ProcessProtocol):
             logger.info("Tunnel process listening on port %r.", self.port)
             client = TunnelClient(LOCALHOST, self.port, self.cookie)
             self.client_d.callback(client)
+
+    def errReceived(self, data):
+        logger.debug("Got stderr from tunnel process: %r", data)
