@@ -45,7 +45,6 @@ from ubuntuone.platform import (
     notification,
     sync_menu
 )
-from ubuntuone.platform.messaging import Messaging
 from ubuntuone.platform.launcher import UbuntuOneLauncher, DummyLauncher
 
 ONE_DAY = 24 * 60 * 60
@@ -176,7 +175,7 @@ class StatusEvent(object):
 
     MESSAGE_ONE = None  # to be defined in child classes
     WEIGHT = 99
-    DO_NOT_INSTANCE = "Do not instance this class, only children."""
+    DO_NOT_INSTANCE = "Do not instance this class, only children."
 
     def __init__(self, **kwargs):
         """Initialize this instance."""
@@ -616,6 +615,7 @@ class StatusAggregator(object):
         self.progress = {}
         self.to_do = {}
         self.recent_transfers = deque(maxlen=5)
+        self.connection_listeners = []
         self.progress_listeners = []
 
     def get_notification(self):
@@ -654,6 +654,13 @@ class StatusAggregator(object):
         else:
             raise TypeError("Callable object expected.")
 
+    def register_connection_listener(self, listener):
+        """Register a callable object to be notified."""
+        if isinstance(listener, Callable):
+            self.connection_listeners.append(listener)
+        else:
+            raise TypeError("Callable object expected.")
+
     def get_discovery_message(self):
         """Get the text for the discovery bubble."""
         lines = []
@@ -746,6 +753,9 @@ class StatusAggregator(object):
         if command.deflated_size is not None:
             self.progress[
                 (command.share_id, command.node_id)] = command.deflated_size
+        if command.path in self.recent_transfers:
+            self.recent_transfers.remove(command.path)
+        self.recent_transfers.append(command.path)
         logger.debug("unqueueing command: %s", command.__class__.__name__)
         self.update_progressbar()
 
@@ -777,6 +787,8 @@ class StatusAggregator(object):
         if command.deflated_size is not None:
             self.progress[
                 (command.share_id, command.node_id)] = command.deflated_size
+        if command.path in self.recent_transfers:
+            self.recent_transfers.remove(command.path)
         self.recent_transfers.append(command.path)
         logger.debug("unqueueing command: %s", command.__class__.__name__)
         self.update_progressbar()
@@ -793,10 +805,14 @@ class StatusAggregator(object):
     def connection_lost(self):
         """The connection to the server was lost."""
         self.file_discovery_bubble.connection_lost()
+        for callback in self.connection_listeners:
+            callback(False)
 
     def connection_made(self):
         """The connection to the server was made."""
         self.file_discovery_bubble.connection_made()
+        for callback in self.connection_listeners:
+            callback(True)
 
 
 class StatusFrontend(object):
@@ -806,7 +822,6 @@ class StatusFrontend(object):
         """Initialize this instance."""
         self.aggregator = StatusAggregator(clock=clock)
         self.notification = self.aggregator.get_notification()
-        self.messaging = Messaging()
         self.quota_timer = None
 
         self.syncdaemon_service = service
@@ -818,22 +833,33 @@ class StatusFrontend(object):
         if self.syncdaemon_service is not None:
             self.sync_menu = sync_menu.UbuntuOneSyncMenu(self,
                 self.syncdaemon_service)
+            self.aggregator.register_connection_listener(
+                self.sync_menu.sync_status_changed)
             self.aggregator.register_progress_listener(
                 self.sync_menu.update_transfers)
 
     def recent_transfers(self):
-        """Return a tuple with the recent transfers paths."""
+        """Return a list of paths of recently transferred files."""
         return list(self.aggregator.recent_transfers)
 
     def files_uploading(self):
-        """Return a list with the files being uploading."""
+        """Return list with (path, size, written) per current upload."""
         uploading = []
         for upload in self.aggregator.files_uploading:
-            if upload.size != 0:
-                uploading.append((upload.path, upload.size,
+            if upload.deflated_size not in (0, None):
+                uploading.append((upload.path, upload.deflated_size,
                     upload.n_bytes_written))
         return uploading
 
+    def files_downloading(self):
+        """Returns list with (path, size, read) per current download."""
+        downloading = []
+        for download in self.aggregator.files_downloading:
+            if download.deflated_size not in (0, None):
+                downloading.append((download.path, download.deflated_size,
+                                    download.n_bytes_read))
+        return downloading
+
     def file_published(self, public_url):
         """A file was published."""
         status_event = FilePublishingStatus(new_public_url=public_url)
@@ -872,7 +898,6 @@ class StatusFrontend(object):
 
     def new_share_available(self, share):
         """A new share is available for subscription."""
-        self.messaging.show_message(share.other_visible_name)
         self.notification.send_notification(
             UBUNTUONE_TITLE, ShareAvailableStatus(share=share).one())
 
