@@ -183,7 +183,8 @@ def get_config_files():
     if os.path.exists(config_file):
         config_files.append(config_file)
 
-    config_logs = os.path.join('data', CONFIG_LOGS)
+    config_logs = os.path.join(os.path.dirname(__file__), os.path.pardir,
+                               os.path.pardir, 'data', CONFIG_LOGS)
     if os.path.exists(config_logs):
         config_files.append(config_logs)
 
