@@ -33,6 +33,7 @@
 from __future__ import with_statement
 
 import os
+import re
 import time
 import functools
 import itertools
@@ -324,7 +325,7 @@ class FileSystemManager(object):
 
     def __init__(self, data_dir, partials_dir, vm, db):
         if not isinstance(data_dir, basestring):
-            raise TypeError("data_dir should be a string instead of %s" % \
+            raise TypeError("data_dir should be a string instead of %s" %
                             type(data_dir))
         fsmdir = os.path.join(data_dir, 'fsm')
         self._trash_dir = os.path.join(data_dir, 'trash')
@@ -1363,6 +1364,27 @@ class FileSystemManager(object):
 
         return all_paths
 
+    def get_paths_by_pattern(self, search, ignore_shares=True):
+        """Get list of paths matching 'search'. option: ignore shares to me"""
+        search = '.+'.join(re.escape(search).split('\\ '))
+        pattern = re.compile(search, re.IGNORECASE)
+
+        def _get_matching():
+            """Find the paths that match"""
+            for p, m in self._idx_path.iteritems():
+                mdobj = self.fs[m]
+                # ignore shares that are not root (root is id='')
+                # and ignore files not present on the server
+                if ((ignore_shares and
+                    mdobj["share_id"] != '' and
+                    mdobj["share_id"] in self.vm.shares)
+                    or not mdobj["server_hash"]):
+                    continue
+                if pattern.search(p):
+                    yield p
+
+        return sorted(_get_matching())
+
     def delete_to_trash(self, mdid, parent_id):
         """Move the node to the trash."""
         mdobj = self.fs[mdid]
