@@ -46,7 +46,8 @@ from functools import wraps
 
 from twisted.internet import defer
 
-from ubuntu_sso.networkstate import NetworkManagerState, ONLINE
+from ubuntu_sso.networkstate import NetworkManagerState
+from ubuntu_sso.networkstate.networkstates import ONLINE
 
 from ubuntuone.logger import log_call
 from ubuntuone.platform import credentials, ExternalInterface
@@ -401,6 +402,12 @@ class SyncdaemonFileSystem(SyncdaemonObject):
             dirty_nodes.append(self._mdobj_dict(mdobj))
         return dirty_nodes
 
+    @unicode_to_bytes
+    @log_call(logger.debug, with_result=False)
+    def search_files(self, pattern):
+        """Search for the occurrence of pattern in the files names."""
+        return self.fs_manager.get_paths_by_pattern(pattern)
+
 
 class SyncdaemonShares(SyncdaemonObject):
     """An interface to interact with shares."""
