@@ -1,9 +1,6 @@
-# ubuntuone.syncdaemon.interfaces - ActionQueue interface
+# -*- coding: utf-8 -*-
 #
-# Authors: John Lenton <john.lenton@canonical.com>
-#          Lucio Torre <lucio.torre@canonical.com>
-#
-# Copyright 2009 Canonical Ltd.
+# Copyright 2009-2012 Canonical Ltd.
 #
 # This program is free software: you can redistribute it and/or modify it
 # under the terms of the GNU General Public License version 3, as published
@@ -16,14 +13,26 @@
 #
 # You should have received a copy of the GNU General Public License along
 # with this program.  If not, see <http://www.gnu.org/licenses/>.
-"""
-This is the interface of the ActionQueue
-"""
+#
+# In addition, as a special exception, the copyright holders give
+# permission to link the code of portions of this program with the
+# OpenSSL library under certain conditions as described in each
+# individual source file, and distribute linked combinations
+# including the two.
+# You must obey the GNU General Public License in all respects
+# for all of the code used other than OpenSSL.  If you modify
+# file(s) with this exception, you may extend this exception to your
+# version of the file(s), but you are not obligated to do so.  If you
+# do not wish to do so, delete this exception statement from your
+# version.  If you delete this exception statement from all source
+# files in the program, then also delete it here.
+"""This is the interface of the ActionQueue."""
 
 from zope.interface import Interface, Attribute
 
 # pylint: disable-msg=W0232,E0213,E0211
 
+
 class IContentQueue(Interface):
     """
     The content queue is the part of access queue that manages uploads
@@ -47,18 +56,12 @@ class IContentQueue(Interface):
         however.
         """
 
-    def download(share_id, node_id, server_hash, path, fileobj_factory):
-        """
-        Go get the content for the given node and dump it into
-        file-like object fileobj.
-        """
+    def download(share_id, node_id, server_hash, path):
+        """Go get the content for the given node."""
+
+    def upload(share_id, node_id, previous_hash, hash, crc32, size, path):
+        """Upload the content of the node."""
 
-    def upload(share_id, node_id, previous_hash, hash, crc32,
-               size, path, fileobj_factory):
-        """
-        Put the content of file-like object fileobj up in the given
-        node.
-        """
 
 class IMetaQueue(Interface):
     """
@@ -222,4 +225,3 @@ class IMarker(Interface):
     """
     A marker interface for telling server uuids apart from markers.
     """
-
