@@ -467,16 +467,15 @@ class SyncStateMachineRunner(StateMachineRunner):
         self.key.delete_metadata()
         self.new_file(event, params, share_id, node_id, parent_id, name)
 
-    def get_file(self, event, params, hash):
+    def get_file(self, event, params, server_hash):
         """Get the contents for the file."""
-        self.key.set(server_hash=hash)
+        self.key.set(server_hash=server_hash)
         self.key.sync()
         share_id = self.key['share_id']
         node_id = self.key['node_id']
-        path = self.key['path']
+        mdid = self.key['mdid']
         self.m.fs.create_partial(node_id=node_id, share_id=share_id)
-        self.m.action_q.download(share_id=share_id, node_id=node_id,
-                                 server_hash=hash, path=path)
+        self.m.action_q.download(share_id, node_id, server_hash, mdid)
 
     def reget_file(self, event, params, hash):
         """cancel and reget this download."""
@@ -499,6 +498,11 @@ class SyncStateMachineRunner(StateMachineRunner):
         share_id = self.key['share_id']
         node_id = self.key['node_id']
 
+        # fix first the PathLockTree, so the move hooks on it's final
+        # path, if any
+        self.m.action_q.pathlock.fix_path(tuple(path_from.split(os.path.sep)),
+                                          tuple(path_to.split(os.path.sep)))
+
         self.m.action_q.move(share_id, node_id, old_parent_id,
                              new_parent_id, new_name, path_from, path_to)
         self.m.fs.add_to_move_limbo(share_id, node_id, old_parent_id,
@@ -540,8 +544,9 @@ class SyncStateMachineRunner(StateMachineRunner):
         self.key.set(server_hash=empty_hash)
         self.key.sync()
         name = os.path.basename(path)
-        marker = MDMarker(self.key.get_mdid())
-        self.m.action_q.make_file(share_id, parent_id, name, marker, path)
+        mdid = self.key.get_mdid()
+        marker = MDMarker(mdid)
+        self.m.action_q.make_file(share_id, parent_id, name, marker, mdid)
 
     def release_marker_ok(self, event, parms, new_id, marker):
         """Release ok the received marker in AQ's DeferredMap."""
@@ -573,7 +578,7 @@ class SyncStateMachineRunner(StateMachineRunner):
         name = os.path.basename(path)
         mdid = self.key.get_mdid()
         marker = MDMarker(mdid)
-        self.m.action_q.make_dir(share_id, parent_id, name, marker, path)
+        self.m.action_q.make_dir(share_id, parent_id, name, marker, mdid)
         self.m.lr.scan_dir(mdid, path)
 
     def new_local_dir_created(self, event, parms, new_id, marker):
@@ -594,29 +599,30 @@ class SyncStateMachineRunner(StateMachineRunner):
         self.m.action_q.cancel_upload(share_id=self.key['share_id'],
                                       node_id=self.key['node_id'])
 
+        mdid = self.key.get_mdid()
         local_hash = self.key['local_hash']
         previous_hash = self.key['server_hash']
         crc32 = self.key['crc32']
         size = self.key['size']
         share_id = self.key['share_id']
         node_id = self.key['node_id']
-        path = self.key['path']
         upload_id = self.key.get('upload_id')
 
         self.m.action_q.upload(share_id, node_id, previous_hash, local_hash,
-                               crc32, size, path, upload_id=upload_id)
+                               crc32, size, mdid, upload_id=upload_id)
 
-    def put_file(self, event, params, hash, crc32, size, stat):
+    def put_file(self, event, params, current_hash, crc32, size, stat):
         """Upload the file to the server."""
+        mdid = self.key.get_mdid()
+        share_id = self.key['share_id']
+        node_id = self.key['node_id']
         previous_hash = self.key['server_hash']
-        path = self.key['path']
         upload_id = self.key.get('upload_id')
-        self.key.set(local_hash=hash, stat=stat, crc32=crc32, size=size)
+        self.key.set(local_hash=current_hash, stat=stat, crc32=crc32, size=size)
         self.key.sync()
 
-        self.m.action_q.upload(share_id=self.key['share_id'],
-            node_id=self.key['node_id'], previous_hash=previous_hash,
-            hash=hash, crc32=crc32, size=size, path=path, upload_id=upload_id)
+        self.m.action_q.upload(share_id, node_id, previous_hash, current_hash,
+                               crc32, size, mdid, upload_id=upload_id)
 
     def converges_to_server(self, event, params, hash, crc32, size, stat):
         """the local changes now match the server"""
@@ -635,19 +641,21 @@ class SyncStateMachineRunner(StateMachineRunner):
         self.key.sync()
         self.m.hash_q.insert(self.key['path'], self.key['mdid'])
 
-    def reput_file(self, event, param, hash, crc32, size, stat):
+    def reput_file(self, event, param, current_hash, crc32, size, stat):
         """Put the file again."""
         self.m.action_q.cancel_upload(share_id=self.key['share_id'],
                             node_id=self.key['node_id'])
         previous_hash = self.key['server_hash']
 
-        path = self.key['path']
+        share_id = self.key['share_id']
+        node_id = self.key['node_id']
         upload_id = self.key.get('upload_id')
-        self.key.set(local_hash=hash, stat=stat, crc32=crc32, size=size)
+        self.key.set(local_hash=current_hash, stat=stat,
+                      crc32=crc32, size=size)
         self.key.sync()
-        self.m.action_q.upload(share_id=self.key['share_id'],
-            node_id=self.key['node_id'], previous_hash=previous_hash,
-            hash=hash, crc32=crc32, size=size, path=path, upload_id=upload_id)
+        mdid = self.key.get_mdid()
+        self.m.action_q.upload(share_id, node_id, previous_hash, current_hash,
+                               crc32, size, mdid, upload_id=upload_id)
 
     def server_file_now_matches(self, event, params, hash):
         """We got a server hash that matches local hash"""
